<?php
/**
 * Use this script to customize your attack detection.
 */

/**
 * Hook function for custom attack detection.
 *
 * @param array  $a_fields    the fields to detect
 * @param string $s_attack    returns the name of the attack
 * @param string $s_info      returns more info about the attack
 * @param string $s_user_info returns info about the attack to display to the user
 *
 * @return bool true if an attack is detected
 */
function FMHookDetectAttacks($a_fields,&$s_attack,&$s_info,&$s_user_info)
{
	foreach ($a_fields as $s_fld => $s_value) {
		$s_lower = strtolower($s_fld);
		if (strpos($s_lower,'name') !== false && strlen($s_value) >= 5) {
			if (preg_match('/^[a-f0-9]+$/i',$s_value)) {
				$s_attack = 'Numeric name';
				$s_info   = $s_user_info = 'Hexadecimal attack';
				return true;
			}
		}
	}
	return false;
}


if ((float) $FM_VERS < 9.15) {   // version 9.15 or later uses FMHookDetectAttacks automatically.
	/**
	 * Wrapper function to call FMHookDetectAttacks.
	 */
	function RunCustomDetection()
	{
		global $aFormVars;

		if (FMHookDetectAttacks($aFormVars,$s_attack,$s_info,$s_user_info)) {
			if (function_exists('FMHookAttacked')) {
				FMHookAttacked('');
			} /* in the future, pass the type of attack */
			if (Settings::get('ALERT_ON_ATTACK_DETECTION')) {
				SendAlert(GetMessage(MSG_ATTACK_DETECTED,
				                     array("ATTACK" => $s_attack,
				                           "INFO"   => $s_info,
				                     )),
				          false);
			}
			if (!IsAjax() && Settings::get('ATTACK_DETECTION_URL') !== "") {
				Redirect(Settings::get('ATTACK_DETECTION_URL'),GetMessage(MSG_FORM_ERROR));
			} else {
				global $SERVER;

				CreatePage(GetMessage(MSG_ATTACK_PAGE,array("SERVER" => $SERVER,"USERINFO" => $s_user_info)),
				           GetMessage(MSG_FORM_ERROR));
			}
			exit;
		}
	}
	if (Settings::get('ENABLE_ATTACK_DETECTION')) {
		RunCustomDetection();
	}
}